@@ -58,7 +58,7 @@ EXPECTED_EXECUTIONS = [
         'configurable': False,
         'authenticationFlow': True,
         'level': 1,
-        'index': 3,
+        'index': 4,
         'priority': 30,
     },
     {
@@ -97,6 +97,42 @@ EXPECTED_EXECUTIONS = [
         'index': 1,
         'priority': 20,
     },
+    {
+        'requirement': 'ALTERNATIVE',
+        'displayName': 'Organization Identity-First Login',
+        'index': 1,
+        'level': 3,
+        'priority': 20,
+        'providerId': 'organization',
+        'configurable': True,
+    },
+    {
+        'configurable': False,
+        'displayName': 'Condition - user configured',
+        'index': 0,
+        'level': 3,
+        'priority': 10,
+        'providerId': 'conditional-user-configured',
+        'requirement': 'REQUIRED',
+    },
+    {
+        'authenticationFlow': True,
+        'configurable': False,
+        'displayName': 'Organization (browser flow with legacy app authorization)',
+        'index': 3,
+        'level': 1,
+        'priority': 26,
+        'requirement': 'ALTERNATIVE',
+    },
+    {
+        'authenticationFlow': True,
+        'configurable': False,
+        'displayName': 'Browser - Conditional Organization (browser flow with legacy app authorization)',
+        'index': 0,
+        'level': 2,
+        'priority': 10,
+        'requirement': 'CONDITIONAL',
+    },
     {
         'requirement': 'REQUIRED',
         'displayName': 'Univention App Authenticator',
