@@ -115,6 +115,15 @@ def keycloak_app_version() -> str:
     return version[0]
 
 
+@pytest.fixture()
+def tracing_page(page, request: pytest.FixtureRequest, ucr_proper):
+    page.context.tracing.start(screenshots=True, snapshots=True)
+
+    yield page
+
+    fixtures.teardown_umc_browser_test(request, ucr_proper, page, page.context, page.context.browser)
+
+
 @pytest.fixture()
 def change_app_setting():
     data = {'app': None, 'configure': None, 'changes': {}}
@@ -244,7 +253,7 @@ def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
         'password_id': 'password',
         'login_error_css_selector': "span[class='pf-c-alert__title kc-feedback-text']",
         'password_update_error_css_selector': "span[class='pf-c-alert__title kc-feedback-text']",
-        'wrong_password_msg': 'Invalid username or password.',
+        'wrong_password_msg': 'The authentication has failed, please login again.',
         'wrong_password_msg_de': 'Ungültiger Benutzername oder Passwort.',
         'kc_passwd_update_form_id': 'kc-passwd-update-form',
         'password_confirm_id': 'password-confirm',
@@ -265,9 +274,10 @@ def browser_context_args(browser_context_args):
 
 @pytest.fixture(scope='session')
 def browser_type_launch_args(browser_type_launch_args):
+    os.environ['LANG'] = 'en_US.UTF-8'
+    del browser_type_launch_args['executable_path']
     return {
         **browser_type_launch_args,
-        'executable_path': '/usr/bin/chromium',
         'args': [
             '--disable-gpu',
         ],
@@ -318,8 +328,8 @@ def __portal_login_func(
 
 
 @pytest.fixture()
-def portal_login_via_keycloak(page: Page, portal_config: SimpleNamespace, keycloak_config: SimpleNamespace):
-    return functools.partial(__portal_login_func, portal_config, keycloak_config, page)
+def portal_login_via_keycloak(tracing_page: Page, portal_config: SimpleNamespace, keycloak_config: SimpleNamespace):
+    return functools.partial(__portal_login_func, portal_config, keycloak_config, tracing_page)
 
 
 @pytest.fixture()
@@ -328,7 +338,9 @@ def portal_login_via_keycloak_custom_page(portal_config: SimpleNamespace, keyclo
 
 
 @pytest.fixture()
-def keycloak_adm_login(page: Page, keycloak_config: SimpleNamespace):
+def keycloak_adm_login(tracing_page: Page, keycloak_config: SimpleNamespace):
+    page = tracing_page
+
     def _func(
         username: str,
         password: str,
@@ -454,6 +466,7 @@ def legacy_authorization_setup_oidc(
     user_dn, user_name = udm.create_user(password='univention')
     client = f'testclient-{user_name}'
     client_secret = 'abc'
+    client_id = None
     groups = {group_name: client}
 
     try:
@@ -482,9 +495,10 @@ def legacy_authorization_setup_oidc(
         )
     finally:
         # cleanup
-        run_command(['univention-keycloak', 'legacy-authentication-flow', 'delete', '--flow', 'direct grant'])
         legacy_auth_config_remove(keycloak_administrator_connection, groups)
-        keycloak_administrator_connection.delete_client(client_id)
+        if client_id:
+            keycloak_administrator_connection.delete_client(client_id)
+        run_command(['univention-keycloak', 'legacy-authentication-flow', 'delete', '--flow', 'direct grant'])
 
 
 @pytest.fixture()
